<?php

namespace pareviewsh\Checks;

use \JsonSerializable;
use \pareviewsh\CheckBase;
use \pareviewsh\CheckInterface;
use \pareviewsh\CheckIssue;
use \pareviewsh\IssueStatisticsInterface;

/**
 * PAReview.sh Drupal Git repository check.
 *
 * Checks a Git repository for compatibility with Drupal.org's
 * package scripts.
 */
class DrupalGitRepositoryCheck extends CheckBase implements CheckInterface, IssueStatisticsInterface, JsonSerializable {

  /**
   * {@inheritdoc}
   */
  public static function getId() {
    return 'drupal:git';
  }

  /**
   * {@inheritdoc}
   */
  public static function getPriority() {
    // Make sure Git tests occur before any other tests.
    return -10;
  }

  /**
   * {@inheritdoc}
   */
  public static function requiresGit() {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public static function getName() {
    return 'Git repository';
  }

  public static function getDescription() {
    return "Checks the Git repository for compatibility with Drupal.org's package scripts.";
  }

  public function run() {
    $this->issues->addIssue(new CheckIssue([
      'message' => 'Could not run Git check!!!',
      'severity' => 'error',
      'test_id' => self::getId(),
    ]));
    $this->issues->addIssue(new CheckIssue([
      'message' => 'sadff ogujm oij gh eueghd siuhd iupdyf rbnkdjdfh bd;kjvh pufynou hiufhnv phuehr fg oiu hfvksjfdnvpdudy f-wedngvkj dhfpuwe fgh ewfg hjkvh oapugfh cpi gsdgfi mipoeqerf',
      'severity' => 'warning',
      'test_id' => self::getId(),
    ]));
    $this->issues->addIssue(new CheckIssue([
      'message' => 'Could nius goiujer novujqo[eidgujn o[iamhjfgueoir vtyydu amvhdajger oitnm dffuhgju uergh dehefgoi go ier hgjnujdfhgiro eeoueghuiohg ot run Git check!!!',
      'severity' => 'notice',
      'test_id' => self::getId(),
    ]));

    $this->status = self::CHECK_STATUS_UNKNOWN;
    return $this->status;
  }

  /**
   * {@inheritdoc}
   */
  public function jsonSerialize() {
    return array_merge(parent::jsonSerialize(), [
      'id' => self::getId(),
      'priority' => self::getPriority(),
      'name' => self::getName(),
      'description' => self::getDescription(),
    ]);
  }

}
