<?php

namespace pareviewsh;

/**
 * Interface for adding file related sub-issues to an issue.
 */
interface FilesIssueInterface {

  /**
   * Add a file related issue as child.
   *
   * @param \pareviewsh\FileIssueInterface $file_issue
   *   File issue to add.
   *
   * @throws \pareviewsh\Exceptions\RuntimeException
   *   If the file name could not be resolved from the file issue.
   */
  public function addFileIssue(FileIssueInterface $file_issue);

  /**
   * Whether this issue has file related sub issues.
   *
   * @return bool
   *   TRUE, if it has file related sub issues, FALSE otherwise.
   */
  public function hasFileIssues();

  /**
   * Return all file related sub issues.
   *
   * @return array<string, \pareviewsh\FileIssues>
   *   Associative array keyed by file name having related file
   *   issues wrappers as values.
   */
  public function getFileIssues();

}
