<?php

namespace pareviewsh;

/**
 * Interface for issues wrappers.
 *
 * Issues wrappers hold a collection of issues that are related
 * to a certain check/file or file.
 * 
 * Additionally, they provide means to count issues of a certain
 * type.
 */
interface IssuesInterface extends IssueStatisticsInterface {

  /**
   * Add an issue.
   *
   * @param \pareviewsh\IssueInterface $issue
   *   Issue to add.
   */
  public function addIssue(IssueInterface $issue);

  /**
   * Return all issues.
   *
   * @return \pareviewsh\IssueInterface[]
   *   Array of issues.
   */
  public function getIssues();

  /**
   * Sorts issues by occurrence in ascending order.
   *
   * @return \pareviewsh\IssuesInterface
   *   Issues sorted by occurrence.
   */
  public function sortByOccurrence();

}
