<?php

namespace pareviewsh\Parser;

use \pareviewsh\FileIssue;
use \pareviewsh\ParserInterface;
use \pareviewsh\Utils\SourceFile;

class ParallelLintJsonParser implements ParserInterface {

  /**
   * {@inheritdoc}
   */
  public static function parse($data, $testId = '', array $issues = []) {
    $workspace = \pareviewsh\Pareview::getInstance()->getConfig()->workspace;
    $data = json_decode($data, TRUE);
    if (!empty($data['results']['errors'])) {
      foreach($data['results']['errors'] as $dataset) {
        $issue = [
          'severity' => 'error',
          'message' => str_replace($workspace, '.', preg_replace('~ in ' . preg_quote($dataset['file']) . ' on line [0-9]+$~', '.', $dataset['normalizeMessage'])),
          'file' => $dataset['file'],
          'line' => $dataset['line'],
          'test_id' => $testId,
          'rule_id' => $dataset['type'],
          'column' => 0,
        ];
        $source_file = new SourceFile($dataset['file']);
        $issue['proof'] = $source_file->extractSource($issue['line']);
        $source_file = null;
        $issues[] = new FileIssue($issue);
      }
    }

    return $issues;
  }

}
