<?php

namespace pareviewsh;

/**
 * Report parser interface.
 *
 * Reports provide helper methods to parse input data from
 * (external) tools to \pareviewsh\Issues.
 *
 * @see \pareviewsh\Issues
 */
interface ParserInterface {

  /*
   * Parse the given data for issues and return them as PAReview.sh Issues.
   *
   * @param string $data
   *   Data as given from output of (external) tools.
   * @param string $testId
   *   [Optional] Identifier for the test that produced the data.
   *   Defaults to an empty string.
   * @param \pareviewsh\FileIssueInterface[] $issues
   *   [Optional] Initial issues array. Parsed issues will be added.
   *   Defaults to an empty array.
   *
   * @return \pareviewsh\FileIssueInterface[]
   *   Issues extracted from the input data.
   */
  public static function parse($data, $testId = '', array $issues = []);

}
