<?php

namespace pareviewsh\Reports;

use \pareviewsh\Pareview;
use \pareviewsh\ReportInterface;
use \pareviewsh\Utils\Output;

/**
 * "classic" report class for PAReview.sh results.
 *
 * The "classic" format is a minimal HTML report format using
 * only H[2-4], UL, OL, LI, P, BR, B, I and CODE tags.
 *
 * It derived from the PAReview.sh 7.x-1.x output format and is
 * suitable for a comment in the drupal.org Project Applications
 * issue queue.
 */
class ClassicReport implements ReportInterface {

  /**
   * {@inheritdoc}
   */
  public function printReport(Pareview $pareview, Output $output) {
    $details = json_decode(json_encode($pareview), TRUE);

    $title = '';
    if (!empty($details['project_name'])) {
      $title = 'project "' . $details['name'] . '"';
    }
    else if (!empty($details['project_id'])) {
      $title = 'project "' . $details['id'] . '"';
    }
    else if (!empty($details['git_repository'])) {
      $title = 'repository "' . $details['git_repository'] . '"';
    }
    else if (!empty($pareview->getConfig()->directory)) {
      $title = 'directory "' . $pareview->getConfig()->directory . '"';
    }
    $output->writeLn(sprintf('<h2>%s</h2>' . PHP_EOL, 'Review ' . (empty($title) ? 'results' : 'of ' . $title)));
    if (empty($details['warnings']) && empty($details['errors'])) {
      $output->writeLn('Great work! No issues found.' . PHP_EOL);
    }
    else {
      $output->writeLn('<ul>');
      foreach ($details['checks'] as $check) {
        if ($check['has_issues']) {
          if (!empty($check['issues_general'])) {
            foreach ($check['issues_general'] as $issue) {
              $output->writeLn(sprintf('<li>%s</li>', $issue['message']));
            }
          }
          if ($check['issues_files']) {
            $output->write('<li>');
            $output->writeLn($check['issues_description']);
            $output->writeLn('<ul>');
            foreach($check['issues_files'] as $file) {
              $output->writeLn('<li>' . $file['file'] . ' ');
              $output->write('<pre>');
              $last = array_values(array_slice($file['issues'], -1))[0];
              $max_length = strlen($last['line']);
              $prefix = str_repeat(' ', $max_length) . ' |         | ';
              foreach ($file['issues'] as $line) {
                $output->writeLn(' ' . str_pad($line['line'], $max_length) . ' | ' . str_pad(strtoupper($line['severity']), 7) . ' | ' . \pareviewsh\Utils\MiscUtil::wrap($line['message'], 1, 1, 70, $prefix));
              }
              $output->writeLn('</pre></li>');
            }
            $output->writeLn('</ul>');
            $output->writeLn('</li>');
          }
        }
      }
      $output->writeLn('</ul>');
    }
  }

}
