<?php

namespace pareviewsh;

/**
 * PAReview.sh tool interface.
 */
interface ToolInterface {

  /**
   * Whether the tool can run on the current environment.
   *
   * @return bool
   *   TRUE, if the tool can run on the current environment,
   *   FALSE otherwise.
   */
  public static function canRun();

  /**
   * Run tool for files specified.
   *
   * @param array $files
   *   [Optional] Files/directories to be inspected. If no or an empty
   *   argument is given,all files in the PAReview workspace will be
   *   inspected.
   *
   * @return int
   *   Tool exit code.
   */
  public function run(array $files = []);

  /**
   * Return the output of the tool.
   *
   * @return string
   *   Output of the tool.
   */
  public function getOutput();

  /**
   * Return the errors produced by the tool.
   *
   * @return string
   *   Output of the tool.
   */
  public function getErrors();

}
