<?php

namespace pareviewsh\Tools;

use \pareviewsh\Config;
use \pareviewsh\Pareview;
use \pareviewsh\ToolInterface;
use \pareviewsh\Utils\CliCommand;

/**
 * CLI wrapper for PHP CodeSniffer.
 */
class PhpLint implements ToolInterface, ExtensionInterface {

  /**
   * Output generated by running parallel-lint.
   *
   * @var string
   */
  private $output;

  /**
   * Error messages generated by parallel-lint.
   *
   * @var string
   */
  private $errors;

  /**
   * List of extensions for tool run.
   *
   * @var array
   */
  private $extensions;

  /**
   * Return the path to the CLI wrapper of parallel-lint.
   *
   * @return string
   *   Parallel lint path.
   */
  protected static function getCommand() {
    return realpath(Config::getBinDir() . '/parallel-lint');
  }

  /**
   * {@inheritdoc}
   */
  public static function canRun() {
    // Whether a potentially executable file was found.
    $command = self::getCommand();
    if (empty($command)) {
      return FALSE;
    }

    // Try executing the command.
    $cli = new CliCommand();
    $output = '';
    $exit_code = $cli->exec($command . ' --version', NULL, $output);
    return ($exit_code === 0 && !empty($output) && empty($cli->getErrors()));
  }

  /**
   * Construct a PHP Parallel Lint tool instance.
   */
  public function __construct() {
    $this->output = '';
    $this->errors = '';
    $this->extensions = array_keys(Config::getFormattersByExtension());
  }

  /**
   * {@inheritdoc}
   */
  public function setExtensions(array $extensions) {
    $this->extensions = $extensions;
  }

  /**
   * {@inheritdoc}
   */
  public function getErrors() {
    return $this->errors;
  }

  /**
   * {@inheritdoc}
   */
  public function getOutput() {
    return $this->output;
  }

  /**
   * {@inheritdoc}
   */
  public function run(array $files = []) {
    if (empty($files)) {
      $files = [Pareview::getInstance()->getConfig()->workspace];
    }

    foreach ($files as &$file) {
      $file = escapeshellarg($file);
    }

    $command = [self::getCommand()];
    $command[] = '--no-progress';
    $command[] = '--json';
    if (!empty($this->extensions)) {
      $command[] = '-e';
      $command[] = escapeshellarg(implode(',', $this->extensions));
    }

    $cli = new CliCommand();
    $output = '';
    $exit_code = $cli->exec(implode(' ', $command) . ' ' . implode(' ', $files), NULL, $output);

    $this->output = $output;
    $this->errors = $cli->getErrors();

    return $exit_code;
  }

}
