<?php

namespace pareviewsh\Utils;

/**
 * Source file.
 */
class SourceFile extends \SplFileObject {

  /**
   * Extracts a code snippet proof from the file.
   *
   * Rather than only extracting a single line from the source code,
   * this method allows to additionally extract lines before and after
   * the line. This enables to preview issues like missing empty lines
   * before or after the actual line.
   *
   * @param int $line
   *   Line number to extract.
   * @param int $before
   *   Optional line numbers to be extracted before the actual line.
   *   Defaults to 1.
   * @param int $after
   *   Optional line numbers to be extracted after the actual line.
   *   Defaults to 1.
   *
   * @return array
   *   An associative proof array with the following keys:
   *   - start: The line number where the snippet starts.
   *   - lines: Array holding the extracted lines.
   *   - eof: Boolean indicating, whether the file ends after the snippet.
   */
  public function extractSource($line, $before = 1, $after = 1) {
    $start = $line > $before ? $line - $before : 1;
    $lines = [];
    $index = $start - 1;
    $this->seek($index);
    while(!$this->eof() && $index < $line + $after) {
      $lines[] = $this->current();
      $this->seek(++$index);
    }
    $result = [
      'start' => $start,
      'lines' => $lines,
      'eof' => $this->eof(),
    ];
    return $result;
  }

}
